##### Potsdam Mind Research Repository ######

## This script is part of the publication package for the article:

# Cajar, A., Schneeweiß, P., Engbert, R., & Laubrock, J. (2016).
# Coupling of attention and saccades when viewing scenes with central and peripheral degradation.
# Journal of Vision.
# doi:10.1167/16.2.8

# Anke Cajar, 2016


######## Generate statistics and figures for Experiment 1 #########

rm(list=ls())

# packages
library(MASS)
library(lme4)
library(RColorBrewer)
library(plyr)
library(Hmisc)

# load data
Df <- readRDS("Exp1.rds")

# colors for figures
clrs <- c(brewer.pal(9,"Greys")[9],brewer.pal(9,"YlOrRd")[8],brewer.pal(9,"Set1")[2])


### Eye movements ###

## Saccade amplitude ##

# prepare data
sactab <- subset(Df, sacinvalid==0 & critfix==0)

# linear mixed-model
m1.sa <- lmer(lambdaampl ~ conexp + type + loc + type_loc + 
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc || imageid), 
              data=sactab, REML=FALSE)  

summary(m1.sa, corr=FALSE)

# plot mean saccade amplitudes
aggrtab.sa <- ddply(sactab, .(subject,condition), summarise, samean=mean(amplitudeDeg))
GM.sa <- mean(aggrtab.sa$samean)
aggrtab.sa <- ddply(aggrtab.sa, .(subject), transform, sa_norm=samean-mean(samean)+GM.sa) # remove between-subject variance for within-subjects error bars (after Cousineau, 2005) 

nl=nlevels(aggrtab.sa$condition)
mf = sqrt(nl/(nl-1)) # Morey factor for correcting Cousineau's error bars (Morey, 2008)

sa.table <- ddply(aggrtab.sa, .(condition), summarise, N=length(samean), M=mean(samean), M_norm=mean(sa_norm),
                  SD=sd(samean), SD_normed=sd(sa_norm), 
                  SE=SD_normed/sqrt(N)*mf,
                  CI=SE*qt(.975, N-1))
(sa.table <- sa.table[c(1,5:2),])

x <- c(1,rep(2:3,2))
plot(x,sa.table$M, type="p", lty="solid", pch=c(15,rep(16,4)), 
     col=c(clrs[1],rep(clrs[2:3],each=2)), 
     xlim=c(0.5,3.5), 
     ylim=c(4.6,8.5),
     xlab="Filter location", 
     ylab="Saccade amplitude [deg]",
     xaxt="n")
axis(side=1,at=c(1:3),labels=c("No filter","Periphery","Center"))

lines(x[2:3],sa.table$M[2:3],col=clrs[2],lwd=2)
lines(x[4:5],sa.table$M[4:5],col=clrs[3],lwd=2)

par(fg=clrs[1])
errbar(x[1],sa.table$M[1], yplus=sa.table$M[1]+sa.table$CI[1], yminus=sa.table$M[1]-sa.table$CI[1], cap=0.025,
       add=T, col=clrs[1], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[2])
errbar(x[2:3],sa.table$M[2:3], yplus=sa.table$M[2:3]+sa.table$CI[2:3], yminus=sa.table$M[2:3]-sa.table$CI[2:3], cap=0.025, 
       add=T, col=clrs[2], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[3])
errbar(x[4:5],sa.table$M[4:5], yplus=sa.table$M[4:5]+sa.table$CI[4:5], yminus=sa.table$M[4:5]-sa.table$CI[4:5], cap=0.025,
       add=T, col=clrs[3], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  

par(fg="black")
box(col="black")
legend(0.5,8.5,legend=c("No filter","Low-pass","High-pass"),pch=c(15,16,16),lwd=2,col=clrs,bty="n",title=expression(bold("Filter type")))

# plot amplitude distributions
NBINSAMPL <- 45
AMPLMIN <- 0
AMPLMAX <- 39
LOGAMPLMIN <- -2
saccond <- levels(sactab$condition)[c(1,4,5,2,3)]
logampl <- log(sactab$amplitudeDeg)
LOGAMPLMAX <- log(AMPLMAX)
hlogampl <- list()
dlogampl <- list()
a <- 1.2
grplbls <- c("Control", "Central low-pass", "Peripheral low-pass", "Central high-pass", "Peripheral high-pass") 

logamplbins <- seq(from=LOGAMPLMIN, to=LOGAMPLMAX,  length.out=NBINSAMPL)
amplbins <- seq(from=0, to=AMPLMAX,  length.out=NBINSAMPL)

for (i in 1:length(saccond)) {
  ix <- sactab$condition==saccond[i]
  hlogampl[[i]] <- hist(logampl[ix], breaks=logamplbins, plot=FALSE) 
  dlogampl[[i]] <- density(logampl[ix], adjust=a)
}

disclrs <- c(clrs[1],rep(clrs[2:3],each=2))
ltype <- c("solid","dashed","solid","dashed","solid")

plot(hlogampl[[1]]$mids, hlogampl[[1]]$density, lwd=2,
     col=clrs[1], 
     cex=.7,
     ylim = c(0,.85), 
     xlab = "Saccade amplitude [deg]",
     ylab = "Density",
     xaxt="n")
axis(side=1, at=-2:3, labels=sprintf('%4.1f', exp(-2:3))) 
for (i in 2:length(saccond)){
  points(hlogampl[[i]]$mids, hlogampl[[i]]$density, col=disclrs[i], cex=.7, lwd=2) 
  lines(dlogampl[[i]], col=disclrs[i], lwd=2, lty=ltype[i])  
}
lines(dlogampl[[1]], lty=ltype[1], lwd=2, col=clrs[1])
legend(-2.1,.865, grplbls, col=disclrs, lwd=2, lty=ltype, bty="n")


## Fixation duration ##

# prepare data
fixtab <- subset(Df, fixinvalid==0 & critfix==0)

# linear mixed model
m.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc + 
               (conexp + type + loc + type_loc | subject) + 
               (conexp + type + loc + type_loc || imageid), 
             data=fixtab, REML=FALSE)  

summary(m.fd, corr=FALSE)

# plot mean fixation durations
aggrtab.fd <- ddply(fixtab, .(subject,condition), summarise, fdmean=mean(fixdur))
GM.fd <- mean(aggrtab.fd$fdmean)
aggrtab.fd <- ddply(aggrtab.fd, .(subject), transform, fd_norm=fdmean-mean(fdmean)+GM.fd) # remove between-subject variance for within-subjects error bars (after Cousineau, 2005) 

nl=nlevels(aggrtab.fd$condition)
mf = sqrt(nl/(nl-1)) # Morey factor for correcting Cousineau's error bars (Morey, 2008)

fd.table <- ddply(aggrtab.fd, .(condition), summarise, N=length(fdmean), M=mean(fdmean), M_norm=mean(fd_norm),
                  SD=sd(fdmean), SD_normed=sd(fd_norm), 
                  SE=SD_normed/sqrt(N)*mf,
                  CI=SE*qt(.975, N-1))
(fd.table <- fd.table[c(1,5:2),])

x <- c(1,rep(2:3,2))
plot(x,fd.table$M, type="p", lty="solid", pch=c(15,rep(16,4)), 
     col=c(clrs[1],rep(clrs[2:3],each=2)), 
     xlim=c(0.5,3.5), 
     ylim=c(245,307),
     xlab="Filter location", 
     ylab="Fixation duration [ms]",
     xaxt="n")
axis(side=1,at=c(1:3),labels=c("No filter","Periphery","Center"))

lines(x[4:5],fd.table$M[4:5],col=clrs[3],lwd=2)
lines(x[2:3],fd.table$M[2:3],col=clrs[2],lwd=2)

par(fg=clrs[1])
errbar(x[1],fd.table$M[1], yplus=fd.table$M[1]+fd.table$CI[1], yminus=fd.table$M[1]-fd.table$CI[1], cap=0.025,
       add=T, col=clrs[1], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[2])
errbar(x[2:3],fd.table$M[2:3], yplus=fd.table$M[2:3]+fd.table$CI[2:3], yminus=fd.table$M[2:3]-fd.table$CI[2:3], cap=0.025, 
       add=T, col=clrs[2], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[3])
errbar(x[4:5],fd.table$M[4:5], yplus=fd.table$M[4:5]+fd.table$CI[4:5], yminus=fd.table$M[4:5]-fd.table$CI[4:5], cap=0.025,
       add=T, col=clrs[3], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  

par(fg="black")
box(col="black")
legend(0.5,307,legend=c("No filter","Low-pass","High-pass"),pch=c(15,16,16),lwd=2,col=clrs,bty="n",title=expression(bold("Filter type")))


### Task performance ###

## Memory questions ##

# prepare data
anstab <- subset(Df, fixno==1 & answer!=0)

# generalized linear mixed-model
m1.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + 
                 (1 | subject) + 
                 (1 | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m1.ac, corr=FALSE)

## Target detection probability ##

# prepare data
dettab <- subset(Df, critfixinvalid==0)

# generalized linear mixed model
m1.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + 
                 (conHPC + conHPP + conLPC || subject) + 
                 (conHPC + conHPP || imageid), 
               data = crittab, family = binomial(link="logit"))

summary(m1.dp, corr=FALSE)

# plot mean target detection probabilities
aggrtab.dp <- ddply(dettab, .(subject,condition), summarise, dpmean=mean(responsegiven))
GM.dp <- mean(aggrtab.dp$dpmean)
aggrtab.dp <- ddply(aggrtab.dp, .(subject), transform, dp_norm=dpmean-mean(dpmean)+GM.dp) # remove between-subject variance for within-subjects error bars (after Cousineau, 2005) 

nl=nlevels(aggrtab.dp$condition)
mf = sqrt(nl/(nl-1)) # Morey factor for correcting Cousineau's error bars (Morey, 2008)

dp.table <- ddply(aggrtab.dp, .(condition), summarise, N=length(dpmean), M=mean(dpmean), M_norm=mean(dp_norm),
                  SD=sd(dpmean), SD_normed=sd(dp_norm), 
                  SE=SD_normed/sqrt(N)*mf,
                  CI=SE*qt(.975, N-1))
(dp.table <- dp.table[c(1,5:2),])

x <- c(1,rep(2:3,2))
plot(x,dp.table$M, type="p", lty="solid", pch=c(15,rep(16,4)), 
     col=c(clrs[1],rep(clrs[2:3],each=2)), 
     xlim=c(0.5,3.5), 
     ylim=c(0.5,0.97),
     xlab="Filter location", 
     ylab="Target detection probability",
     xaxt="n")
axis(side=1,at=c(1:3),labels=c("No filter","Periphery","Center"))

lines(x[2:3],dp.table$M[2:3],col=clrs[2],lwd=2)
lines(x[4:5],dp.table$M[4:5],col=clrs[3],lwd=2)

par(fg=clrs[1])
errbar(x[1],dp.table$M[1], yplus=dp.table$M[1]+dp.table$CI[1], yminus=dp.table$M[1]-dp.table$CI[1], cap=0.025,
       add=T, col=clrs[1], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[3])
errbar(x[4:5],dp.table$M[4:5], yplus=dp.table$M[4:5]+dp.table$CI[4:5], yminus=dp.table$M[4:5]-dp.table$CI[4:5], cap=0.025,
       add=T, col=clrs[3], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[2])
errbar(x[2:3],dp.table$M[2:3], yplus=dp.table$M[2:3]+dp.table$CI[2:3], yminus=dp.table$M[2:3]-dp.table$CI[2:3], cap=0.025, 
       add=T, col=clrs[2], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  

points(x[3],dp.table$M[3],pch=16,col=clrs[2])

par(fg="black")
box(col="black")
legend(0.5,0.97,legend=c("No filter","Low-pass","High-pass"),pch=c(15,16,16),lwd=2,col=clrs,bty="n",title=expression(bold("Filter type")))


## Target response time ##

# prepare data
rttab <- subset(Df, critfixinvalid==0 & rt!=-99)
rttab <- subset(rttab, rt>260 & rt<1200)

# generalized linear mixed model
m1.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP | subject) + 
                (conHPC | imageid), 
              data=rttab, REML=FALSE)  

summary(m1.rt, corr=FALSE)

# plot mean target response times
aggrtab.rt <- ddply(rttab, .(subject,condition), summarise, rtmean=mean(rt))
GM.rt <- mean(aggrtab.rt$rtmean)
aggrtab.rt <- ddply(aggrtab.rt, .(subject), transform, rt_norm=rtmean-mean(rtmean)+GM.rt) # remove between-subject variance for within-subjects error bars (after Cousineau, 2005) 

nl=nlevels(aggrtab.rt$condition)
mf = sqrt(nl/(nl-1)) # Morey factor for correcting Cousineau's error bars (Morey, 2008)

rt.table <- ddply(aggrtab.rt, .(condition), summarise, N=length(rtmean), M=mean(rtmean), M_norm=mean(rt_norm),
                  SD=sd(rtmean), SD_normed=sd(rt_norm), 
                  SE=SD_normed/sqrt(N)*mf,
                  CI=SE*qt(.975, N-1))
(rt.table <- rt.table[c(1,5:2),])

x <- c(1,rep(2:3,2))
plot(x,rt.table$M, type="p", lty="solid", pch=c(15,rep(16,4)), 
     col=c(clrs[1],rep(clrs[2:3],each=2)), 
     xlim=c(0.5,3.5), 
     ylim=c(535,640),
     xlab="Filter location", 
     ylab="Reaction time [ms]",
     xaxt="n")
axis(side=1,at=c(1:3),labels=c("No filter","Periphery","Center"))

lines(x[4:5],rt.table$M[4:5],col=clrs[3],lwd=2)
lines(x[2:3],rt.table$M[2:3],col=clrs[2],lwd=2)

par(fg=clrs[1])
errbar(x[1],rt.table$M[1], yplus=rt.table$M[1]+rt.table$CI[1], yminus=rt.table$M[1]-rt.table$CI[1], cap=0.025,
       add=T, col=clrs[1], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[3])
errbar(x[4:5],rt.table$M[4:5], yplus=rt.table$M[4:5]+rt.table$CI[4:5], yminus=rt.table$M[4:5]-rt.table$CI[4:5], cap=0.025,
       add=T, col=clrs[3], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  
par(fg=clrs[2])
errbar(x[2:3],rt.table$M[2:3], yplus=rt.table$M[2:3]+rt.table$CI[2:3], yminus=rt.table$M[2:3]-rt.table$CI[2:3], cap=0.025, 
       add=T, col=clrs[2], lty="solid", lwd=2, xlab=c(""), ylab=c(""))  

par(fg="black")
box(col="black")
legend(0.5,640,legend=c("No filter","Low-pass","High-pass"),pch=c(15,16,16),lwd=2,col=clrs,bty="n",title=expression(bold("Filter type")))


## Target detection probability as a function of saccade length ##

# prepare data
angtab <- subset(Df, sacinvalid==0 & angleinvalid==0 & critfixinvalid==0)

# generalized linear mixed model
m1.sl <- glmer(responsegiven ~ sl5 + sl10 + 
                 (sl5 + sl10 | subject) + 
                 (sl5 || imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m1.sl, corr=FALSE)

# plot detection probability as a function of target-saccade angle and saccade amplitude
startix <- c(22,-1,-23,-68,-113,-158,180,157,112,67)
endix <- c(0,-22,-67,-112,-157,-179,158,113,68,23)  

for ( i in 1:length(startix) ) {
  start <- startix[i]
  end <- endix[i]  
  angtab$angrange[angtab$angle<=start & angtab$angle>=end] <- sprintf("%d - %d", start, end)  
}

angtab$angrange[angtab$angrange=="22 - 0"] <- "22 - -22"
angtab$angrange[angtab$angrange=="-1 - -22"] <- "22 - -22"
angtab$angrange[angtab$angrange=="-158 - -179"] <- "-158 - 158"
angtab$angrange[angtab$angrange=="180 - 158"] <- "-158 - 158"

angtab$angrange <- factor(angtab$angrange)
levels(angtab$angrange)

angtab$saclength <- factor(angtab$saclength, levels=c("< 5°","5-10°","> 10°"))

ampls <- levels(angtab$saclength)
angs <- levels(angtab$angrange)
detprob <- data.frame(saclength=rep(ampls,each=8), angrange=rep(angs,length(ampls)), prob=NA, ndata=NA)
k <- 0
for ( i in 1:length(ampls)) {
  for ( j in 1:length(angs)) {
    ampl <- ampls[i]
    ang <- angs[j]
    k <- k + 1
    ix <- which(angtab$saclength==ampl & angtab$angrange==ang)
    detprob[k,3] <- sum(angtab$responsegiven[ix]) / length(angtab$responsegiven[ix])
    detprob[k,4] <- length(angtab$responsegiven[ix])
  }
}
print(detprob)
detprob$saclength <- factor(detprob$saclength, levels=c("< 5°","5-10°","> 10°"))
detprob$angrange <- factor(detprob$angrange, levels=c("-23 - -67", "-68 - -112", "-113 - -157", "-158 - 158", "157 - 113", "112 - 68", "67 - 23", "22 - -22"))

p <- ggplot(detprob, aes(x=angrange,y=saclength,fill=prob)) + 
  geom_tile() + 
  coord_polar(start=22.5*pi/180) + 
  theme_bw(base_size=20) + 
  labs(x="Target-saccade angle [deg arc]",y="Saccade amplitude [deg visual angle]",fill="Detection\n probability") +
  scale_x_discrete(labels=c("-45°","-90°","-135°","+/-180°","135°","90°","45°","0°")) 
print(p)
