##### Potsdam Mind Research Repository ######

## This script is part of the publication package for the article:

# Cajar, A., Schneeweiß, P., Engbert, R., & Laubrock, J. (2016).
# Coupling of attention and saccades when viewing scenes with central and peripheral degradation.
# Journal of Vision.
# doi:10.1167/16.2.8

# Anke Cajar, 2016


######## Identify (G)LMMs with proper random-effects structure for Experiment 1 #########

rm(list=ls())

# packages
library(MASS)
library(lme4)
library(RePsychLing)

# load data
Df <- readRDS("Exp1.rds")


### Eye movements ###

## Saccade amplitude ##

# prepare data
sactab <- subset(Df, sacinvalid==0 & critfix==0)

# maximal model:
m1.sa <- lmer(lambdaampl ~ conexp + type + loc + type_loc + # fails to converge
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=sactab, REML=FALSE)  

summary(m1.sa, corr=FALSE)
summary(rePCA(m1.sa)) 

# zero-correlation-parameter (zcp) models: 
m2.sa <- lmer(lambdaampl ~ conexp + type + loc + type_loc + 
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc || imageid), 
              data=sactab, REML=FALSE)  

summary(m2.sa, corr=FALSE)
summary(rePCA(m2.sa)) # looks good

m3.sa <- lmer(lambdaampl ~ conexp + type + loc + type_loc + # fails to converge
                (conexp + type + loc + type_loc || subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=sactab, REML=FALSE)  

# FINAL MODEL: m2.sa


## Fixation duration ##

# prepare data
fixtab <- subset(Df, fixinvalid==0 & critfix==0)

# maximal model:
m1.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc + # fails to converge
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=fixtab, REML=FALSE)  

summary(m1.fd, corr=FALSE)
summary(rePCA(m1.fd))

# zcp models:
m2.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc + 
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc || imageid), 
              data=fixtab, REML=FALSE)  

summary(m2.fd, corr=FALSE)
summary(rePCA(m2.fd)) # looks good

m3.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc + # fails to converge
                (conexp + type + loc + type_loc || subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=fixtab, REML=FALSE)  


# FINAL MODEL: m2.fd


### Task performance ###

## Memory questions ##

# prepare data
anstab <- subset(Df, fixno==1 & answer!=0)

# maximal model:
m1.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m1.ac, corr=FALSE)
summary(rePCA(m1.ac))

# zcp models:
m2.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = anstab, family = binomial(link="logit"))

m3.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = anstab, family = binomial(link="logit"))

m4.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m4.ac, corr=FALSE)
summary(rePCA(m4.ac)) # remove all slopes for imageid; remove conLPP and conLPC for subject


m5.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP || subject) + 
                 (1 | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m5.ac, corr=FALSE)
summary(rePCA(m5.ac)) # remove conHPP for subject

m6.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + 
                 (conHPC || subject) + 
                 (1 | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m6.ac, corr=FALSE)
summary(rePCA(m6.ac)) # remove conHPC for subject

m7.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + 
                 (1 | subject) + 
                 (1 | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m7.ac, corr=FALSE)
summary(rePCA(m7.ac))

# FINAL MODEL: m7.ac


## Target detection probability ##

# prepare data
dettab <- subset(Df, critfixinvalid==0)

# maximal model:
m1.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m1.dp, corr=FALSE)
summary(rePCA(m1.dp))

# zcp models:
m2.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = dettab, family = binomial(link="logit"))

m3.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = dettab, family = binomial(link="logit"))

m4.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m4.dp, corr=FALSE)
summary(rePCA(m4.dp)) # remove conLPP for subject and imageid

m5.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + 
                 (conHPC + conHPP + conLPC || subject) + 
                 (conHPC + conHPP + conLPC || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m5.dp, corr=FALSE)
summary(rePCA(m5.dp)) # remove conLPC for imageid

m6.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + 
                 (conHPC + conHPP + conLPC || subject) + 
                 (conHPC + conHPP || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m6.dp, corr=FALSE)
summary(rePCA(m6.dp)) # looks good

# try to add correlations again
m7.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC || subject) + 
                 (conHPC + conHPP | imageid), 
               data = dettab, family = binomial(link="logit"))

m8.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC | subject) + 
                 (conHPC + conHPP || imageid), 
               data = dettab, family = binomial(link="logit"))

m9.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC | subject) + 
                 (conHPC + conHPP | imageid), 
               data = dettab, family = binomial(link="logit"))

# FINAL MODEL: m6.dp


## Target response time ##

# prepare data
rttab <- subset(Df, critfixinvalid==0 & rt!=-99)
rttab <- subset(rttab, rt>260 & rt<1200)

# maximal model:
m1.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP + conLPC + conLPP | subject) + 
                (conHPC + conHPP + conLPC + conLPP | imageid), 
              data=rttab, REML=FALSE)  

summary(m1.rt, corr=FALSE)
summary(rePCA(m1.rt)) # remove conLPP for subject and imageid

m2.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                (conHPC + conHPP + conLPC | subject) + 
                (conHPC + conHPP + conLPC | imageid), 
              data=rttab, REML=FALSE)  

summary(m2.rt, corr=FALSE)
summary(rePCA(m2.rt)) # remove conLPC for subject; remove conHPP and conLPC for imageid

m3.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP | subject) + 
                (conHPC | imageid), 
              data=rttab, REML=FALSE)  

summary(m3.rt, corr=FALSE)
summary(rePCA(m3.rt)) # looks good

anova(m1.rt, m3.rt) # not significant: prefer m3.rt

# FINAL MODEL: m3.rt


## Target detection probability as a function of saccade length

# prepare data
angtab <- subset(Df, sacinvalid==0 & angleinvalid==0 & critfixinvalid==0)

# maximal model:
m1.sl <- glmer(responsegiven ~ sl5 + sl10 + # fails to converge
                 (sl5 + sl10 | subject) + 
                 (sl5 + sl10 | imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m1.sl, corr=FALSE)
summary(rePCA(m1.sl))

# zcp models:
m2.sl <- glmer(responsegiven ~ sl5 + sl10 + 
                 (sl5 + sl10 | subject) + 
                 (sl5 + sl10 || imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m2.sl, corr=FALSE)
summary(rePCA(m2.sl)) # remove sl10 for imageid

m3.sl <- glmer(responsegiven ~ sl5 + sl10 + 
                 (sl5 + sl10 | subject) + 
                 (sl5 || imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m3.sl, corr=FALSE)
summary(rePCA(m3.sl)) # looks good

# try to add correlations again
m4.sl <- glmer(responsegiven ~ sl5 + sl10 + # fails to converge
                 (sl5 + sl10 | subject) + 
                 (sl5 | imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m4.sl, corr=FALSE)

# FINAL MODEL: m3.sl
