##### Potsdam Mind Research Repository ######

## This script is part of the publication package for the article:

# Cajar, A., Schneeweiß, P., Engbert, R., & Laubrock, J. (2016).
# Coupling of attention and saccades when viewing scenes with central and peripheral degradation.
# Journal of Vision.
# doi:10.1167/16.2.8

# Anke Cajar, 2016


######## Identify (G)LMMs with proper random-effects structure for Experiment 2 #########


rm(list=ls())

# packages
library(MASS)
library(lme4)
library(RePsychLing)

# load data
Df <- readRDS("Exp2.rds")


### Eye movements ###

## Saccade amplitude ##

# prepare data
sactab <- subset(Df, sacinvalid==0 & critfix==0)

# maximal model:
m1.sa <- lmer(lambdaampl ~ conexp + type + loc + type_loc + 
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=sactab, REML=FALSE)  

summary(m1.sa, corr=FALSE)
summary(rePCA(m1.sa)) # looks good

# FINAL MODEL: m1.sa


## Fixation duration ##

# prepare data
fixtab <- subset(Df, fixinvalid==0 & critfix==0)

# maximal model:
m1.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc + # fails to converge
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=fixtab, REML=FALSE)  

summary(m1.fd, corr=FALSE)
summary(rePCA(m1.fd)) 

# zcp models:
m2.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc +
                (conexp + type + loc + type_loc | subject) + 
                (conexp + type + loc + type_loc || imageid), 
              data=fixtab, REML=FALSE)  

summary(m2.fd, corr=FALSE)
summary(rePCA(m2.fd)) # looks good

m3.fd <- lmer(logfixdur ~ conexp + type + loc + type_loc +
                (conexp + type + loc + type_loc || subject) + 
                (conexp + type + loc + type_loc | imageid), 
              data=fixtab, REML=FALSE)  

summary(m3.fd, corr=FALSE)
summary(rePCA(m3.fd)) # remove type_loc for imageid -> prefer m2.fd

# FINAL MODEL: m2.fd


### Task performance ###

## Memory questions ##

# prepare data
anstab <- subset(Df, fixno==1 & answer!=0)

# maximal model:
m1.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m1.ac, corr=FALSE)
summary(rePCA(m1.ac))

# zcp models:
m2.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = anstab, family = binomial(link="logit"))

m3.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = anstab, family = binomial(link="logit"))

m4.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m4.ac, corr=FALSE)
summary(rePCA(m4.ac)) # remove conLPC and conLPP for subject and imageid

m5.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP || subject) + 
                 (conHPC + conHPP || imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m5.ac, corr=FALSE)
summary(rePCA(m5.ac)) # remove conHPP for subject and imageid

m6.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC || subject) + 
                 (conHPC || imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m6.ac, corr=FALSE)
summary(rePCA(m6.ac)) # remove conHPC for subject and imageid

m7.ac <- glmer(answercorrect ~ conHPC + conHPP + conLPC + conLPP + 
                 (1 | subject) + 
                 (1 | imageid), 
               data = anstab, family = binomial(link="logit"))

summary(m7.ac, corr=FALSE)
summary(rePCA(m7.ac)) 

# FINAL MODEL: m7.ac


## Target detection probability ##

# prepare data
dettab <- subset(Df, critfixinvalid==0)

# maximal model:
m1.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m1.dp, corr=FALSE)
summary(rePCA(m1.dp))

# zcp models:
m2.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP | subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m2.dp, corr=FALSE)
summary(rePCA(m2.dp))

m3.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP | imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m3.dp, corr=FALSE)
summary(rePCA(m3.dp))

m4.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC + conLPP || subject) + 
                 (conHPC + conHPP + conLPC + conLPP || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m4.dp, corr=FALSE)
summary(rePCA(m4.dp)) # remove conLPP for subject and imageid

m5.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP + conLPC || subject) + 
                 (conHPC + conHPP + conLPC || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m5.dp, corr=FALSE)
summary(rePCA(m5.dp)) # remove conLPC for subject and imageid

m6.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP +
                 (conHPC + conHPP || subject) + 
                 (conHPC + conHPP || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m6.dp, corr=FALSE)
summary(rePCA(m6.dp)) # looks good

# try to add correlations again:
m7.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP || subject) + 
                 (conHPC + conHPP | imageid), 
               data = dettab, family = binomial(link="logit"))

m8.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP +
                 (conHPC + conHPP | subject) + 
                 (conHPC + conHPP || imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m8.dp, corr=FALSE)
summary(rePCA(m8.dp)) # variance proportion for conHPP only 0.592 % for subject

anova(m6.dp, m8.dp) # prefer m8.dp

m9.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP +
                  (conHPC | subject) + 
                  (conHPC + conHPP || imageid), 
                data = dettab, family = binomial(link="logit"))

summary(m9.dp, corr=FALSE)
summary(rePCA(m9.dp))  # looks good

anova(m8.dp, m9.dp) # not significant -> prefer m9.dp

m10.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + 
                 (conHPC + conHPP | subject) + 
                 (conHPC + conHPP | imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m10.dp, corr=FALSE)
summary(rePCA(m10.dp)) # remove conHPP for imageid

m11.dp <- glmer(responsegiven ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                 (conHPC + conHPP | subject) + 
                 (conHPC | imageid), 
               data = dettab, family = binomial(link="logit"))

summary(m11.dp, corr=FALSE)
summary(rePCA(m11.dp)) 

# FINAL MODEL: m9.dp


## Target response time ##

# prepare data
rttab <- subset(Df, critfixinvalid==0 & rt!=-99)
rttab <- subset(rttab, rt>240)

# maximal model:
m1.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP + conLPC + conLPP | subject) + 
                (conHPC + conHPP + conLPC + conLPP | imageid), 
              data=rttab, REML=FALSE)  

summary(m1.rt, corr=FALSE)
summary(rePCA(m1.rt)) # remove conLPP for subject and imageid

m2.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP + # fails to converge
                (conHPC + conHPP + conLPC | subject) + 
                (conHPC + conHPP + conLPC | imageid), 
              data=rttab, REML=FALSE)  

summary(m2.rt, corr=FALSE)
summary(rePCA(m2.rt)) # remove conLPC for subject and imageid

m3.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP | subject) + 
                (conHPC + conHPP | imageid), 
              data=rttab, REML=FALSE)  

summary(m3.rt, corr=FALSE)
summary(rePCA(m3.rt)) # remove conHPP for imageid

m4.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP |subject) + 
                (conHPC | imageid), 
              data=rttab, REML=FALSE)  

summary(m4.rt, corr=FALSE)
summary(rePCA(m4.rt)) # remove conHPC for imageid

m5.rt <- lmer(lambdart ~ conHPC + conHPP + conLPC + conLPP +
                (conHPC + conHPP | subject) + 
                (1 | imageid), 
              data=rttab, REML=FALSE)  

summary(m5.rt, corr=FALSE)
summary(rePCA(m5.rt)) # looks good

anova(m1.rt, m5.rt) # not significant -> prefer m5.rt

# FINAL MODEL: m5.rt


## Target detection probability as a function of saccade length ##

# prepare data
angtab <- subset(Df, sacinvalid==0 & angleinvalid==0 & critfixinvalid==0)

# maximal model:
m1.sl <- glmer(responsegiven ~ sl5_10 + sl10 + # fails to converge
                 (sl5_10 + sl10 | subject) + 
                 (sl5_10 + sl10 | imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m1.sl, corr=FALSE)
summary(rePCA(m1.sl))

# zcp models:
m2.sl <- glmer(responsegiven ~ sl5_10 + sl10 + # fails to converge
                 (sl5_10 + sl10 | subject) + 
                 (sl5_10 + sl10 || imageid), 
               data=angtab, family=binomial(link="logit"))

m3.sl <- glmer(responsegiven ~ sl5_10 + sl10 + # fails to converge
                 (sl5_10 + sl10 || subject) + 
                 (sl5_10 + sl10 | imageid), 
               data=angtab, family=binomial(link="logit"))

m4.sl <- glmer(responsegiven ~ sl5_10 + sl10 + # fails to converge
                 (sl5_10 + sl10 || subject) + 
                 (sl5_10 + sl10 || imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m4.sl, corr=FALSE)
summary(rePCA(m4.sl)) # remove all slopes for imageid

m5.sl <- glmer(responsegiven ~ sl5_10 + sl10 + 
                 (sl5_10 + sl10 || subject) + 
                 (1 | imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m5.sl, corr=FALSE)
summary(rePCA(m5.sl)) # looks good

# try to add correlations again
m6.sl <- glmer(responsegiven ~ sl5_10 + sl10 + 
                 (sl5_10 + sl10 | subject) + 
                 (1 | imageid), 
               data=angtab, family=binomial(link="logit"))

summary(m6.sl, corr=FALSE)
summary(rePCA(m6.sl)) # looks good

anova(m5.sl, m6.sl) # prefer m6.sl

# FINAL MODEL: m6.sl 
